==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/MonitorEJB/src/com/clustercontrol/monitor/factory/SelectScope.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.monitor.factory;

import java.util.ArrayList;
import java.util.Date;

import javax.ejb.CreateException;
import javax.ejb.FinderException;
import javax.naming.NamingException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.clustercontrol.bean.PriorityConstant;
import com.clustercontrol.monitor.ejb.entity.EventLogLocal;
import com.clustercontrol.monitor.ejb.entity.StatusInfoLocal;
import com.clustercontrol.monitor.ejb.session.MonitorControllerBean;
import com.clustercontrol.repository.ejb.session.RepositoryControllerLocal;
import com.clustercontrol.repository.ejb.session.RepositoryControllerUtil;
import com.clustercontrol.util.apllog.AplLogger;

/**
 * 󸡺饹
 *
 * @version 1.0.0
 * @since 1.0.0
 */
public class SelectScope {
	
	public static final int PRIORITY = 0;
	public static final int FACILITY_ID = 1;
	public static final int FACILITY_PATH = 2;
	public static final int OUTPUT_DATE = 3;
	
	protected static Log m_log = LogFactory.getLog( SelectScope.class );
	
	/**
	 * װ
	 * 
	 * @param facilityId
	 * @return Object2
	 * @throws CreateException
	 * @throws FinderException
	 * @throws NamingException
	 */
	public ArrayList getScopeList(String facilityId) throws CreateException, FinderException, NamingException {

		ArrayList list = new ArrayList();
		
		SelectStatus selectStatus = new SelectStatus();
		SelectEvent selectEvent = new SelectEvent();
		
		int parentPriority = PriorityConstant.TYPE_NONE;
		String parentFacilityId = null;
		String parentFacilityPath = null;
		Date parentOutputDate = null;

		try 
		{
			RepositoryControllerLocal repository = RepositoryControllerUtil.getLocalHome().create();
			
			// ꤷեƥν٤ֹ⤤
			if(facilityId != null && !"".equals(facilityId)){
				// ٤ֹ⤤ơ
				StatusInfoLocal status = selectStatus.getHighPriorityStatus(facilityId, MonitorControllerBean.ONLY);
				// ٤ֹ⤤٥ȥ
				EventLogLocal event = selectEvent.getHighPriorityEvent(facilityId, MonitorControllerBean.ONLY);
				
				// ٤ֹ⤤ꤹ
				ArrayList info = this.getHighPriorityScope(status, event, repository, facilityId, facilityId);
				
				if(info != null){
					parentPriority = ((Integer)info.get(PRIORITY)).intValue();
					parentFacilityId = (String)info.get(FACILITY_ID);
					parentFacilityPath = (String)info.get(FACILITY_PATH);
					parentOutputDate = (Date)info.get(OUTPUT_DATE);
				}
			}
			
			// ľΥեƥID
			ArrayList facilityIdList = repository.getFacilityIdList(facilityId, MonitorControllerBean.ONE_LEVEL);
			
			String[] facilityIds = null;
			if(facilityIdList != null && facilityIdList.size() > 0){
				// פξ
				facilityIds = new String[facilityIdList.size()];
				facilityIdList.toArray(facilityIds);
			}
			else{
				if(facilityId != null){
					// Ρɤξ
					facilityIds = new String[1];
					facilityIds[0] = facilityId;
				}
				else{
					// ݥȥ꤬1ϿƤʤ
					return null;
				}
			}
			
			// ľΥեƥID°۲ƤΥեƥIDꡢơ٤ֹ⤤
			boolean statusInfoFlg = false;
			boolean eventLogFlg = false;
			boolean highPriorityFlg = false;
			for(int index=0; ((facilityIds!=null) && (index<facilityIds.length)); index++){
				
				// ľΥեƥξ
				if(!facilityIds[index].equals(facilityId)){
					
					// ٤ֹ⤤ơ
					StatusInfoLocal status = selectStatus.getHighPriorityStatus(facilityIds[index], MonitorControllerBean.ALL);
					// ٤ֹ⤤٥ȥ
					EventLogLocal event = selectEvent.getHighPriorityEvent(facilityIds[index], MonitorControllerBean.ALL);
					
					// ٤ֹ⤤ꤹ
					ArrayList info = this.getHighPriorityScope(status, event, repository, facilityIds[index], facilityId);
					if(info != null){
						
						list.add(info);
						
						// Ǿ̤Υեƥξꤹ
						if(parentPriority > ((Integer)info.get(PRIORITY)).intValue()){
							highPriorityFlg = true;
						}
						else if(parentPriority == ((Integer)info.get(PRIORITY)).intValue()){
							if(parentOutputDate != null){
								if(parentOutputDate.before((Date)info.get(OUTPUT_DATE))){
									highPriorityFlg = true;
								}
							}
							else{
								highPriorityFlg = true;
							}
						}
						
						if(highPriorityFlg){
							parentPriority = ((Integer)info.get(PRIORITY)).intValue();
							parentOutputDate = (Date)info.get(OUTPUT_DATE);
							
							if(parentFacilityId == null){
								if(facilityId != null && !"".equals(facilityId)){
									parentFacilityId = facilityId;
									parentFacilityPath = repository.getFacilityPath(facilityId, facilityId);	
								}
							}
						}
					}
				}
				statusInfoFlg = false;
				eventLogFlg = false;
				highPriorityFlg = false;
			}
			
			if(parentFacilityId != null){
				// Ǿ̤Υեƥξꤹ
				ArrayList info = new ArrayList();
				info.add(new Integer(parentPriority));
				info.add(parentFacilityId);
				info.add(parentFacilityPath);
				info.add(parentOutputDate);
				list.add(info);
			}
			
		} catch (CreateException e) {
            AplLogger apllog = new AplLogger("MON", "mon");
            String[] args = {facilityId};
            apllog.put("SYS", "001", args);
			m_log.debug("getScopeList():" + e.getMessage());
			throw e;
		} catch (FinderException e) {
            AplLogger apllog = new AplLogger("MON", "mon");
            String[] args = {facilityId};
            apllog.put("SYS", "001", args);
			m_log.debug("getScopeList():" + e.getMessage());
			throw e;
		} catch (NamingException e) {
            AplLogger apllog = new AplLogger("MON", "mon");
            String[] args = {facilityId};
            apllog.put("SYS", "001", args);
			m_log.debug("getScopeList():" + e.getMessage());
			throw e;
		}
		return list;
	}
	
	/**
	 * ơObject2˳Ǽ
	 * 
	 * @param status
	 * @param event
	 * @param repository
	 * @param parentFacilityId
	 * @return Object1
	 */
	private ArrayList getHighPriorityScope(StatusInfoLocal status, 
			EventLogLocal event, 
			RepositoryControllerLocal repository,
			String facilityId,
			String parentFacilityId) throws CreateException, FinderException, NamingException{
		
		ArrayList info = new ArrayList();
		
		boolean statusInfoFlg = false;
		boolean eventLogFlg = false;
		
		// ٤ֹ⤤ꤹ
		if(status == null && event == null){
			return null;
		}
		else if(status != null && event == null){
			statusInfoFlg = true;
		}
		else if(status == null && event != null){
			eventLogFlg = true;
		}
		else if(status != null && event != null){
			if((status.getPriority()).intValue() < (event.getPriority()).intValue()){
				statusInfoFlg = true;
			}
			else if((status.getPriority()).intValue() > (event.getPriority()).intValue()){
				eventLogFlg = true;
			}
			else if((status.getPriority()).intValue() == (event.getPriority()).intValue()){
				
				// ٤硢Ϻǿξꤹ
				if((status.getOutputDate()).after(event.getOutputDate())){
					statusInfoFlg = true;
				}
				else{
					eventLogFlg = true;
				}
			}
		}
		
		String facilityPath = repository.getFacilityPath(facilityId, parentFacilityId);
		if(statusInfoFlg){
			info.add(status.getPriority());
			info.add(facilityId);
			info.add(facilityPath);
			info.add(new Date(status.getOutputDate().getTime()));
		}
		else if(eventLogFlg){
			info.add(event.getPriority());
			info.add(facilityId);
			info.add(facilityPath);
			info.add(new Date(event.getOutputDate().getTime()));
		}
		return info;
	}
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/MonitorEJB/src/com/clustercontrol/monitor/factory/SelectScope.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.monitor.factory;

import java.util.ArrayList;
import java.util.Date;

import javax.ejb.CreateException;
import javax.ejb.FinderException;
import javax.naming.NamingException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.clustercontrol.bean.PriorityConstant;
import com.clustercontrol.monitor.bean.ScopeTabelDefine;
import com.clustercontrol.monitor.ejb.entity.EventLogLocal;
import com.clustercontrol.monitor.ejb.entity.StatusInfoLocal;
import com.clustercontrol.monitor.ejb.session.MonitorControllerBean;
import com.clustercontrol.repository.ejb.session.RepositoryControllerLocal;
import com.clustercontrol.repository.ejb.session.RepositoryControllerUtil;
import com.clustercontrol.util.apllog.AplLogger;

/**
 * スコープ情報を検索するクラスです。
 *
 * @version 1.0.0
 * @since 1.0.0
 */
public class SelectScope {
	
	/** ログ出力のインスタンス。 */
	protected static Log m_log = LogFactory.getLog( SelectScope.class );
	
	/**
	 * スコープ情報一覧を返します。
	 * <p>
	 * <ol>
	 * <li>引数で指定されたファシリティ(A)の直下のファシリティ（B）を取得します。</li>
	 * <li>取得したファシリティ（B）の配下全てのファシリティ（C）を取得します。</li>
	 * <li>ファシリティ（C）に属するステータス情報／イベント情報から重要度が最高で受信日時が最新のログを取得し、
	 *     ファシリティ（B）のスコープ情報とします。</li>
	 * <li>ファシリティ（B）の重要度が最高で受信日時が最新のログを、ファシリティ（A）のスコープ情報とします。</li>
	 * <li>１スコープ情報をテーブルのカラム順（{@link com.clustercontrol.monitor.bean.ScopeTabelDefine}）に、リスト（{@link ArrayList}）にセットします。</li>
	 * <li>この１スコープ情報を保持するリストを、スコープ情報一覧を保持するリスト（{@link ArrayList}）に格納し返します。<BR>
	 *  <dl>
	 *  <dt>スコープ情報一覧（Objectの2次元配列）</dt>
	 *  <dd>{ スコープ情報1 {カラム1の値, カラム2の値, … }, スコープ情報2{カラム1の値, カラム2の値, …}, … }</dd>
	 *  </dl>
	 * </li>
	 * </ol>
	 * 
	 * @param facilityId 取得対象の親ファシリティID
	 * @return スコープ情報一覧（Objectの2次元配列）
	 * @throws CreateException
	 * @throws FinderException
	 * @throws NamingException
	 * 
	 * @see com.clustercontrol.monitor.factory.SelectStatus#getHighPriorityStatus(String, int)
	 * @see com.clustercontrol.monitor.factory.SelectEvent#getHighPriorityEvent(String, int)
	 * @see com.clustercontrol.monitor.bean.ScopeTabelDefine
	 */
	public ArrayList getScopeList(String facilityId) throws CreateException, FinderException, NamingException {

		ArrayList list = new ArrayList();
		
		SelectStatus selectStatus = new SelectStatus();
		SelectEvent selectEvent = new SelectEvent();
		
		int parentPriority = PriorityConstant.TYPE_NONE;
		String parentFacilityId = null;
		String parentFacilityPath = null;
		Date parentOutputDate = null;

		try 
		{
			RepositoryControllerLocal repository = RepositoryControllerUtil.getLocalHome().create();
			
			// 指定したファシリティの重要度が一番高い情報を取得
			if(facilityId != null && !"".equals(facilityId)){
				// 重要度が一番高いステータス情報を取得
				StatusInfoLocal status = selectStatus.getHighPriorityStatus(facilityId, MonitorControllerBean.ONLY);
				// 重要度が一番高いイベントログを取得
				EventLogLocal event = selectEvent.getHighPriorityEvent(facilityId, MonitorControllerBean.ONLY);
				
				// 重要度が一番高い情報を設定する
				ArrayList info = this.getHighPriorityScope(status, event, repository, facilityId, facilityId);
				
				if(info != null){
					parentPriority = ((Integer)info.get(ScopeTabelDefine.PRIORITY)).intValue();
					parentFacilityId = (String)info.get(ScopeTabelDefine.FACILITY_ID);
					parentFacilityPath = (String)info.get(ScopeTabelDefine.SCOPE);
					parentOutputDate = (Date)info.get(ScopeTabelDefine.UPDATE_TIME);
				}
			}
			
			// 直下のファシリティIDを取得
			ArrayList facilityIdList = repository.getFacilityIdList(facilityId, MonitorControllerBean.ONE_LEVEL);
			
			String[] facilityIds = null;
			if(facilityIdList != null && facilityIdList.size() > 0){
				// スコープの場合
				facilityIds = new String[facilityIdList.size()];
				facilityIdList.toArray(facilityIds);
			}
			else{
				if(facilityId != null){
					// ノードの場合
					facilityIds = new String[1];
					facilityIds[0] = facilityId;
				}
				else{
					// リポジトリが1件も登録されていない場合
					return null;
				}
			}
			
			// 直下のファシリティIDに属する配下全てのファシリティIDより、各々重要度が一番高い情報を取得
			boolean statusInfoFlg = false;
			boolean eventLogFlg = false;
			boolean highPriorityFlg = false;
			for(int index=0; ((facilityIds!=null) && (index<facilityIds.length)); index++){
				
				// 直下のファシリティの場合
				if(!facilityIds[index].equals(facilityId)){
					
					// 重要度が一番高いステータス情報を取得
					StatusInfoLocal status = selectStatus.getHighPriorityStatus(facilityIds[index], MonitorControllerBean.ALL);
					// 重要度が一番高いイベントログを取得
					EventLogLocal event = selectEvent.getHighPriorityEvent(facilityIds[index], MonitorControllerBean.ALL);
					
					// 重要度が一番高い情報を設定する
					ArrayList info = this.getHighPriorityScope(status, event, repository, facilityIds[index], facilityId);
					if(info != null){
						
						list.add(info);
						
						// 最上位のファシリティの情報を設定する
						if(parentPriority > ((Integer)info.get(ScopeTabelDefine.PRIORITY)).intValue()){
							highPriorityFlg = true;
						}
						else if(parentPriority == ((Integer)info.get(ScopeTabelDefine.PRIORITY)).intValue()){
							if(parentOutputDate != null){
								if(parentOutputDate.before((Date)info.get(ScopeTabelDefine.UPDATE_TIME))){
									highPriorityFlg = true;
								}
							}
							else{
								highPriorityFlg = true;
							}
						}
						
						if(highPriorityFlg){
							parentPriority = ((Integer)info.get(ScopeTabelDefine.PRIORITY)).intValue();
							parentOutputDate = (Date)info.get(ScopeTabelDefine.UPDATE_TIME);
							
							if(parentFacilityId == null){
								if(facilityId != null && !"".equals(facilityId)){
									parentFacilityId = facilityId;
									parentFacilityPath = repository.getFacilityPath(facilityId, facilityId);	
								}
							}
						}
					}
				}
				statusInfoFlg = false;
				eventLogFlg = false;
				highPriorityFlg = false;
			}
			
			if(parentFacilityId != null){
				// 最上位のファシリティの情報を設定する
				ArrayList info = new ArrayList();
				info.add(new Integer(parentPriority));
				info.add(parentFacilityId);
				info.add(parentFacilityPath);
				info.add(parentOutputDate);
				list.add(info);
			}
			
		} catch (CreateException e) {
            AplLogger apllog = new AplLogger("MON", "mon");
            String[] args = {facilityId};
            apllog.put("SYS", "001", args);
			m_log.debug("getScopeList():" + e.getMessage());
			throw e;
		} catch (FinderException e) {
            AplLogger apllog = new AplLogger("MON", "mon");
            String[] args = {facilityId};
            apllog.put("SYS", "001", args);
			m_log.debug("getScopeList():" + e.getMessage());
			throw e;
		} catch (NamingException e) {
            AplLogger apllog = new AplLogger("MON", "mon");
            String[] args = {facilityId};
            apllog.put("SYS", "001", args);
			m_log.debug("getScopeList():" + e.getMessage());
			throw e;
		}
		return list;
	}
	
	/**
	 * 重要度が最高で受信日時が最新のスコープ情報を返します。<BR>
	 * 引数で指定されたステータス情報／イベント情報を比較し、
	 * 重要度が最高で受信日時が最新のログの情報を、テーブルのカラム順にリストにセットし返します。
	 * 
	 * @param status ステータス情報
	 * @param event イベント情報
	 * @param repository リポジトリ
	 * @param facilityId 親ファシリティID 
	 * @return スコープ情報
	 */
	private ArrayList getHighPriorityScope(StatusInfoLocal status, 
			EventLogLocal event, 
			RepositoryControllerLocal repository,
			String facilityId,
			String parentFacilityId) throws CreateException, FinderException, NamingException{
		
		ArrayList info = new ArrayList();
		
		boolean statusInfoFlg = false;
		boolean eventLogFlg = false;
		
		// 重要度が一番高い情報を設定する
		if(status == null && event == null){
			return null;
		}
		else if(status != null && event == null){
			statusInfoFlg = true;
		}
		else if(status == null && event != null){
			eventLogFlg = true;
		}
		else if(status != null && event != null){
			if((status.getPriority()).intValue() < (event.getPriority()).intValue()){
				statusInfoFlg = true;
			}
			else if((status.getPriority()).intValue() > (event.getPriority()).intValue()){
				eventLogFlg = true;
			}
			else if((status.getPriority()).intValue() == (event.getPriority()).intValue()){
				
				// 重要度が等しい場合、更新日時は最新の情報を設定する
				if((status.getOutputDate()).after(event.getOutputDate())){
					statusInfoFlg = true;
				}
				else{
					eventLogFlg = true;
				}
			}
		}
		
		String facilityPath = repository.getFacilityPath(facilityId, parentFacilityId);
		if(statusInfoFlg){
			info.add(status.getPriority());
			info.add(facilityId);
			info.add(facilityPath);
			info.add(new Date(status.getOutputDate().getTime()));
		}
		else if(eventLogFlg){
			info.add(event.getPriority());
			info.add(facilityId);
			info.add(facilityPath);
			info.add(new Date(event.getOutputDate().getTime()));
		}
		return info;
	}
}
